@@ -38,6 +38,8 @@ def bam_iter(bam, quiet=False, show_ref_pos=False, callback=None):
     >>> [x.qname for x in bam_iter(bam_open(os.path.join(os.path.dirname(__file__), 't', 'test.bam')), quiet=True)]
     ['A', 'B', 'E', 'C', 'D', 'F', 'Z']
     '''
+
+    
     if not quiet and bam.filename:
         eta = ETA(os.stat(bam.filename).st_size)
     else:
@@ -493,9 +495,19 @@ def region_pos_to_genomic_pos(name, start, cigar):
     >>> region_pos_to_genomic_pos('chr1:1000-1050,2000-2050,3000-4000', 25, [(0, 100)])
     ('chr1', 1025, [(0, 25), (3, 950), (0, 50), (3, 950), (0, 25)])
 
+    >>> region_pos_to_genomic_pos('chr1:1000-1050,1050-1200', 25, [(0, 100)])
+    ('chr1', 1025, [(0, 25), (3, 0), (0, 75)])
+
     >>> region_pos_to_genomic_pos('chr3R:17630851-17630897,17634338-17634384', 17, [(0, 39)])
     ('chr3R', 17630868, [(0, 29), (3, 3441), (0, 10)])
 
+    >>> region_pos_to_genomic_pos('chr1:1000-1050,2000-2050', 25, [(4, 25), (0, 50), (4, 25)])
+    ('chr1', 1025, [(4, 25), (0, 25), (3, 950), (0, 25), (4, 25)])
+
+    >>> region_pos_to_genomic_pos('chr1:1000-1050,2000-2050', 25, [(5, 25), (0, 75)])
+    ('chr1', 1025, [(5, 25), (0, 25), (3, 950), (0, 50)])
+
+
     '''
 
     if name in __region_cache:
@@ -535,7 +547,7 @@ def region_pos_to_genomic_pos(name, start, cigar):
     cur_pos = chr_start
 
     for op, length in cigar:
-        if op == 1:
+        if op in [1, 4, 5]:
             chr_cigar.append((op, length))
 
         elif op in [0, 2]:
@@ -599,6 +611,9 @@ def is_junction_valid(cigar, min_overlap=4):
     >>> is_junction_valid(cigar_fromstr('100M1000N4M'), 4)
     (True, '')
 
+    >>> is_junction_valid(cigar_fromstr('4M0N100M'), 4)
+    (True, '')
+
     '''
     first = True
     pre_gap = True
@@ -705,6 +720,39 @@ def read_cigar_at_pos(cigar, qpos, is_del):
     return None
 
 
+def read_cleancigar(read):
+    '''
+    Cleans the CIGAR string for a read to remove any operations that are zero length.
+    '''
+    if read.is_unmapped:
+        return False
+
+    newcigar = []
+    changed = False
+    last_op = None
+    size_acc = 0
+
+    for op, size in read.cigar:
+        if size > 0:
+            if last_op == op:
+                size_acc += size
+            else:
+                if last_op:
+                    newcigar.append((last_op, size_acc))
+                last_op = op
+                size_acc = size
+        else:
+            changed = True
+
+    newcigar.append((last_op, size_acc))
+
+    if changed:
+        read.cigar = newcigar
+        return True
+
+    return False
+
+
 if __name__ == '__main__':
     import doctest
     doctest.testmod()
